componenttools.copy_governed_component_subtree_by_leaf_range
============================================================

.. autofunction:: abjad.tools.componenttools.copy_governed_component_subtree_by_leaf_range.copy_governed_component_subtree_by_leaf_range
